import { TypedEmitter } from 'tiny-typed-emitter';
import { ProductSchema } from '@byondrnd/showroom-schemas';
export declare type OnSceneLoaded = (eventData: {
    zone: number;
}) => void;
export declare type OnProductChange = (eventData: {
    product: ProductSchema.IProduct;
}) => void;
export declare type OnProductsChange = (eventData: {
    products: ProductSchema.IProduct[];
}) => void;
export declare type onHotspotClicked = (eventData: {
    application: string;
}) => void;
export declare type onProductAddedToFavorite = (eventData: {
    productId: string;
}) => void;
export declare type onSceneAddedToFavorite = (eventData: {
    productIds: string[];
}) => void;
export declare type onProductAddedToCart = (eventData: {
    productId: string;
}) => void;
export declare type onSceneAddedToCart = (eventData: {
    productIds: string[];
}) => void;
export declare type onProductRemovedFromFavorite = (eventData: {
    productId: string;
}) => void;
export declare type onSceneRemovedFromFavorite = (eventData: {
    productIds: string[];
}) => void;
export declare type onProductRemovedFromCart = (eventData: {
    productId: string;
}) => void;
export declare type onSceneRemovedFromCart = (eventData: {
    productIds: string[];
}) => void;
interface IEventSystem {
    sceneLoaded: OnSceneLoaded;
    productChanged: OnProductChange;
    productsChanged: OnProductsChange;
    hotspotClicked: onHotspotClicked;
    productAddedToFavorite: onProductAddedToFavorite;
    sceneAddedToFavorite: onSceneAddedToFavorite;
    productAddedToCart: onProductAddedToCart;
    productRemovedFromFavorite: onProductAddedToFavorite;
    sceneRemovedFromFavorite: onSceneAddedToFavorite;
    productRemovedFromCart: onProductAddedToCart;
}
export declare abstract class EventSystem extends TypedEmitter<IEventSystem> {
    abstract init(): any;
    abstract GetProductList(filters: {
        name: string;
        options: string[];
    }[]): Array<ProductSchema.IProduct>;
    abstract GetHotspotList(): string[];
    abstract GetFilters(): {
        name: string;
        options: string[];
    }[];
    abstract displayProduct(productId: string): Promise<void>;
    abstract addProductToFavorite(productId: string): any;
    abstract addSetToFavorite(productIds: string[]): any;
    abstract addProductsToCart(productIds: string[]): any;
    abstract removeProductFromFavorite(productId: string): any;
    abstract removeSetFromFavorite(productIds: string[]): any;
    abstract removeProductsFromCart(productId: string[]): any;
}
export {};
